# -*- coding: utf-8 -*-
# @Author: Gree
# @Date:   2021-06-02 14:31:12
# @Last Modified by:   Gree
# @Last Modified time: 2021-06-02 14:34:55


import re
import pandas as pd


class ScienceCheck:
    """科学语料自动化分类的检查"""
    def science_check(self, row):
        """
        science_check 函数:
        input:
        output: generator
        features: 科学语料自动化分类的检查
        step1: 检查 science 的语料字段 domain、intent、response_text 是否正确 ✅
        """
        # 获取 domain
        domain = row['domain']
        # 获取 query
        query = row['query']
        # 获取 intent
        intent = row['intent']
        # 获取 response_text
        response_text = row['response_text']

        # 异常捕获
        try:
            # 正则表达式匹配数据规律
            query_result = re.search(r'.*?(加|减|乘|除|等于|次方|光年|换算|长度).*', query)

        except Exception as e:
            print("The error of getting query_result in the module of science_check():", e)

        # 异常捕获
        try:
            # 条件判断
            if query_result is not None and '站在' not in query:
                row['domain_is_right'] = 'yes'

                if 'calculator' in intent or 'unit_' in intent:
                    row['intent_is_right'] = 'yes'
                else:
                    row['intent_is_right'] = 'no'


                if ('等于' in response_text or '单位' in response_text or '做不出来' in response_text) and '24乘以50384乘以59等于' not in query:
                    row['response_is_right'] = 'yes'
                else:
                    row['response_is_right'] = 'no'

                # 生成器
                yield {
                    'date_time': row['date_time'],
                    'request_id': row['request_id'],
                    'mac_wifi': row['mac_wifi'],
                    'user_id': row['user_id'],
                    'query': query,
                    'domain': domain,
                    'intent': intent,
                    'response_text': response_text,
                    'domain_is_right': row['domain_is_right'],
                    'intent_is_right': row['intent_is_right'],
                    'response_is_right': row['response_is_right']
                }

            else:

                # 生成器
                yield {
                    'date_time': row['date_time'],
                    'request_id': row['request_id'],
                    'mac_wifi': row['mac_wifi'],
                    'user_id': row['user_id'],
                    'query': query,
                    'domain': domain,
                    'intent': intent,
                    'response_text': response_text,
                    'domain_is_right': "",
                    'intent_is_right': "",
                    'response_is_right': ""
                }


        except Exception as e:
            print("The error of getting generator in the module of science_check():", e)



