# -*- coding: utf-8 -*-
# @Author: Gree
# @Date:   2021-06-02 14:38:22
# @Last Modified by:   Gree
# @Last Modified time: 2021-06-02 14:43:12


import re
import pandas as pd


class StockCheck:
    """股票语料自动化分类的检查"""
    def stock_check(self, row):
        """
        stock_check 函数:
        input:
        output: generator
        features: 股票语料自动化分类的检查
        step1: 检查 stock 的语料字段 domain、intent、response_text 是否正确 ✅
        """
        # 获取 domain
        domain = row['domain']
        # 获取 query
        query = row['query']
        # 获取 intent
        intent = row['intent']
        # 获取 response_text
        response_text = row['response_text']

        # 异常捕获
        try:
            # 正则表达式匹配数据规律
            query_result = re.search(r'.*?(股|行情|上证|换手率|市盈率|成交|市值|指数|大盘|走势|科创板|收盘).*', query)

        except Exception as e:
            print("The error of getting query_result in the module of stock_check():", e)

        # 异常捕获
        try:
            # 条件判断
            if query_result is not None and '隔壁的' not in query and '天天唠' not in query and '墙头' not in query and '张文斌' not in query and 'Dubbing' not in query and '革命' not in query and '小编' not in query and '一个瓶子' not in query and '安静' not in query and '股份有限公司' not in query and '退出' not in query and '为了炒' not in query and '少佐' not in query and '乔飞' not in query and '一般' not in query:
                row['domain_is_right'] = 'yes'

                if intent is not None:
                    row['intent_is_right'] = 'yes'
                else:
                    row['reply_is_right'] = 'no'

                if response_text is not None and 'S.H.E' not in query:
                    row['response_is_right'] = 'yes'
                else:
                    row['response_is_right'] = 'no'

                # 生成器
                yield {
                    'date_time': row['date_time'],
                    'request_id': row['request_id'],
                    'mac_wifi': row['mac_wifi'],
                    'user_id': row['user_id'],
                    'query': query,
                    'domain': domain,
                    'intent': intent,
                    'response_text': response_text,
                    'domain_is_right': row['domain_is_right'],
                    'intent_is_right': row['intent_is_right'],
                    'response_is_right': row['response_is_right']
                }

            else:

                # 生成器
                yield {
                    'date_time': row['date_time'],
                    'request_id': row['request_id'],
                    'mac_wifi': row['mac_wifi'],
                    'user_id': row['user_id'],
                    'query': query,
                    'domain': domain,
                    'intent': intent,
                    'response_text': response_text,
                    'domain_is_right': "",
                    'intent_is_right': "",
                    'response_is_right': ""
                }

        except Exception as e:
            print("The error of getting generator in the module of stock_check():", e)





